@@ -1,5 +1,14 @@
+use strict;
+use warnings;
 package Devel::REPL::Plugin::CompletionDriver::Keywords;
+BEGIN {
+  $Devel::REPL::Plugin::CompletionDriver::Keywords::AUTHORITY = 'cpan:PHAYLON';
+}
+{
+  $Devel::REPL::Plugin::CompletionDriver::Keywords::VERSION = '1.003022';
+}
 use Devel::REPL::Plugin;
+use Devel::REPL::Plugin::Completion;    # die early if cannot load
 use B::Keywords qw/@Functions @Barewords/;
 use namespace::autoclean;
 
