@@ -1,5 +1,14 @@
+use strict;
+use warnings;
 package Devel::REPL::Plugin::CompletionDriver::Turtles;
+BEGIN {
+  $Devel::REPL::Plugin::CompletionDriver::Turtles::AUTHORITY = 'cpan:PHAYLON';
+}
+{
+  $Devel::REPL::Plugin::CompletionDriver::Turtles::VERSION = '1.003022';
+}
 use Devel::REPL::Plugin;
+use Devel::REPL::Plugin::Completion;    # die early if cannot load
 use namespace::autoclean;
 
 sub BEFORE_PLUGIN {
